#[repr(transparent)]pub struct User {
inner: TypedObjectRef<User, <User as ObjectSubclass>::ParentType>,
phantom: PhantomData<()>,
}Expand description
glib::Object representation of a Matrix user.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<User, <User as ObjectSubclass>::ParentType>phantom: PhantomData<()>Implementations
Sourceimpl User
impl User
Sourcepub fn user_id_string(&self) -> <PhantomData<String> as Property>::Value
pub fn user_id_string(&self) -> <PhantomData<String> as Property>::Value
The ID of this user, as a string.
Sourcepub fn is_own_user(&self) -> <Cell<bool> as Property>::Value
pub fn is_own_user(&self) -> <Cell<bool> as Property>::Value
Whether this user is the same as the session’s user.
Sourcepub fn has_display_name(&self) -> <Cell<bool> as Property>::Value
pub fn has_display_name(&self) -> <Cell<bool> as Property>::Value
Whether this user has a display name set.
If the display name is not set, the display-name property returns
the localpart of the user ID.
Sourcepub fn is_verified(&self) -> <Cell<bool> as Property>::Value
pub fn is_verified(&self) -> <Cell<bool> as Property>::Value
Whether this user has been verified.
Sourcepub fn is_ignored(&self) -> <Cell<bool> as Property>::Value
pub fn is_ignored(&self) -> <Cell<bool> as Property>::Value
Whether this user is currently ignored.
Sourcepub fn connect_user_id_string_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_user_id_string_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the user-id-string property
Sourcepub fn connect_session_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_session_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the session property
Sourcepub fn connect_is_own_user_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_is_own_user_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the is-own-user property
Sourcepub fn connect_has_display_name_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_has_display_name_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the has-display-name property
Sourcepub fn connect_is_verified_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_is_verified_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the is-verified property
Sourcepub fn connect_is_ignored_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_is_ignored_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the is-ignored property
Sourcepub fn notify_user_id_string(&self)
pub fn notify_user_id_string(&self)
Notify listeners of a change in the user-id-string property
Sourcepub fn notify_session(&self)
pub fn notify_session(&self)
Notify listeners of a change in the session property
Sourcepub fn notify_is_own_user(&self)
pub fn notify_is_own_user(&self)
Notify listeners of a change in the is-own-user property
Sourcepub fn notify_has_display_name(&self)
pub fn notify_has_display_name(&self)
Notify listeners of a change in the has-display-name property
Sourcepub fn notify_is_verified(&self)
pub fn notify_is_verified(&self)
Notify listeners of a change in the is-verified property
Sourcepub fn notify_is_ignored(&self)
pub fn notify_is_ignored(&self)
Notify listeners of a change in the is-ignored property
Sourceimpl User
impl User
Sourcepub fn new(session: &Session, user_id: OwnedUserId) -> Self
pub fn new(session: &Session, user_id: OwnedUserId) -> Self
Constructs a new user with the given user ID for the given session.
Sourcepub(crate) async fn ensure_crypto_identity(&self) -> Option<UserIdentity>
pub(crate) async fn ensure_crypto_identity(&self) -> Option<UserIdentity>
Get the cryptographic identity (aka cross-signing identity) of this user.
First, we try to get the local crypto identity if we are sure that it is up-to-date. If we do not have the crypto identity locally, we request it from the homeserver.
Sourcepub(crate) async fn verify_identity(&self) -> Result<IdentityVerification, ()>
pub(crate) async fn verify_identity(&self) -> Result<IdentityVerification, ()>
Start a verification of the identity of this user.
Sourcepub(crate) fn direct_chat(&self) -> Option<Room>
pub(crate) fn direct_chat(&self) -> Option<Room>
The existing direct chat with this user, if any.
A direct chat is a joined room marked as direct, with only our own user and the other user in it.
Sourcepub(crate) async fn get_or_create_direct_chat(&self) -> Result<Room, ()>
pub(crate) async fn get_or_create_direct_chat(&self) -> Result<Room, ()>
Get or create a direct chat with this user.
If there is no existing direct chat, a new one is created.
Sourcepub(crate) async fn stop_ignoring(&self) -> Result<(), ()>
pub(crate) async fn stop_ignoring(&self) -> Result<(), ()>
Stop ignoring this user.